@@ -1,17 +1,14 @@
+# $File: //depot/cpan/Module-Install/lib/Module/Install/Admin.pm $ $Author: autrijus $
+# $Revision: #39 $ $Change: 1509 $ $DateTime: 2003/05/14 13:54:36 $ vim: expandtab shiftwidth=4
+
 package Module::Install::Admin;
+$VERSION = '0.20';
+@ISA = 'Module::Install';
 
 use strict 'vars';
 use File::Path ();
 use inc::Module::Install ();
 
-use vars qw{$VERSION @ISA};
-BEGIN {
-	$VERSION = '0.66_02';
-	@ISA     = qw{Module::Install};
-}
-
-=pod
-
 =head1 NAME
 
 Module::Install::Admin - Author-side manager for Module::Install
@@ -27,7 +24,7 @@ In a B<Module::Install> extension module:
 
 As an one-liner:
 
-    % perl "-MModule::Install::Admin" -e'&some_method(@args);'
+    % perl -MModule::Install::Admin -e'&some_method(@args);'
 
 The two snippets above are really shorthands for
 
@@ -134,36 +131,40 @@ sub copy {
 
     chomp $to;
 
-    local (*FROM, *TO, $_);
+    local (*FROM, *TO, $/);
     open FROM, "< $from" or die "Can't open $from for input:\n$!";
-    open TO,   "> $to"   or die "Can't open $to for output:\n$!";
-    print TO "#line 1\n";
+    my $content = <FROM>;
+    close FROM;
 
-    my $content;
-    my $in_pod;
-
-    while (<FROM>) {
-        if (/^=(?:b(?:egin|ack)|head\d|(?:po|en)d|item|(?:ove|fo)r)/) {
-            $in_pod = 1;
-        }
-        elsif (/^=cut\s*\z/ and $in_pod) {
-            $in_pod = 0;
-            print TO "#line $.\n";
-        }
-        elsif (!$in_pod) {
-            print TO $_;
-        }
+    {
+        local $^W;
+        my $line = 1;
+        $content =~ s{(
+            (.*?)
+            ^=(?:head\d|pod|begin|item|over|for|back|end)\b.*?
+            ^=cut[\t ]*
+            (?:[\r\n])*?
+            (\r?\n)?
+        )}{
+            my ($pre, $post) = ($2, $3);
+            "$pre#line " . (
+                $line += ( () = ( $1 =~ /\n/g ) )
+            ) . $post;
+        }mgsex;
     }
 
-    close FROM;
+    open TO, "> $to" or die "Can't open $to for output:\n$!";
+    print TO "#line 1 \"$to - $from\"\n";
+    print TO $content;
     close TO;
 
     print "include $to\n";
 }
 
-# scan through our target to find
-sub load_all_extensions {
-    my $self = shift;
+sub load {
+    my ($self, $method, $copy) = @_;
+
+    # scan through our target to find
     unless ($self->{extensions}) {
         $self->{extensions} = [];
         foreach my $inc (@INC) {
@@ -171,14 +172,9 @@ sub load_all_extensions {
             $self->load_extensions("$inc/$self->{path}", $self->{_top});
         }
     }
-    return @{$self->{extensions}};
-}
-
-sub load {
-    my ($self, $method, $copy) = @_;
 
     my @extobj;
-    foreach my $obj ($self->load_all_extensions) {
+    foreach my $obj (@{$self->{extensions}}) {
         next unless defined &{ref($obj)."::$method"};
         my $is_admin = (ref($obj) =~ /^\Q$self->{name}::$self->{dispatch}::/);
         # Don't ever include admin modules, and vice versa.
@@ -206,9 +202,7 @@ sub copy_package {
     return if -f $file; # prevents infinite recursion
 
     $self->copy($pathname => $file);
-    foreach my $pkg (@{"$pkg\::ISA"}) {
-        $self->copy_package($pkg);
-    }
+    $self->copy_package($_) for @{"$pkg\::ISA"};
 }
 
 sub pick {
@@ -279,19 +273,17 @@ sub DESTROY {}
 
 __END__
 
-=pod
-
 =head1 SEE ALSO
 
 L<Module::Install>
 
 =head1 AUTHORS
 
-Audrey Tang E<lt>autrijus@autrijus.orgE<gt>
+Autrijus Tang E<lt>autrijus@autrijus.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2003, 2004 by Audrey Tang E<lt>autrijus@autrijus.orgE<gt>.
+Copyright 2003 by Autrijus Tang E<lt>autrijus@autrijus.orgE<gt>.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
